aboutsummaryrefslogtreecommitdiffstats
path: root/activerecord/lib/active_record/connection_adapters/postgresql/schema_definitions.rb
diff options
context:
space:
mode:
authorYaw Boakye <wheresyaw@gmail.com>2016-07-08 03:22:37 +0000
committerYaw Boakye <wheresyaw@gmail.com>2016-11-22 22:11:18 +0000
commitb915b11cca558eb99b7c2621c4457491d4bdb43b (patch)
tree647d9ff0be8cce2d56efa5e589e2e28a5bcd9808 /activerecord/lib/active_record/connection_adapters/postgresql/schema_definitions.rb
parent49aa974ec8b15721d53b3b6abea88bd6ba433a68 (diff)
downloadrails-b915b11cca558eb99b7c2621c4457491d4bdb43b.tar.gz
rails-b915b11cca558eb99b7c2621c4457491d4bdb43b.tar.bz2
rails-b915b11cca558eb99b7c2621c4457491d4bdb43b.zip
For `PostgreSQL >= 9.4` use `gen_random_uuid()`
Since 9.4, PostgreSQL recommends using `pgcrypto`'s `gen_random_uuid()` to generate version 4 UUIDs instead of the functions in the `uuid-ossp` extension. These changes uses the appropriate UUID function depending on the underlying PostgreSQL server's version, while maintaining `uuid_generate_v4()` in older migrations.
Diffstat (limited to 'activerecord/lib/active_record/connection_adapters/postgresql/schema_definitions.rb')
-rw-r--r--activerecord/lib/active_record/connection_adapters/postgresql/schema_definitions.rb17
1 files changed, 9 insertions, 8 deletions
diff --git a/activerecord/lib/active_record/connection_adapters/postgresql/schema_definitions.rb b/activerecord/lib/active_record/connection_adapters/postgresql/schema_definitions.rb
index a11dbe7dce..5d689c2dc3 100644
--- a/activerecord/lib/active_record/connection_adapters/postgresql/schema_definitions.rb
+++ b/activerecord/lib/active_record/connection_adapters/postgresql/schema_definitions.rb
@@ -11,11 +11,12 @@ module ActiveRecord
# t.timestamps
# end
#
# By default, this will use the +uuid_generate_v4()+ function from the
# +uuid-ossp+ extension, which MUST be enabled on your database. To enable
# the +uuid-ossp+ extension, you can use the +enable_extension+ method in your
# migrations. To use a UUID primary key without +uuid-ossp+ enabled, you can
# set the +:default+ option to +nil+:
#
# create_table :stuffs, id: false do |t|
# t.primary_key :id, :uuid, default: nil
@@ -23,15 +24,15 @@ module ActiveRecord
# t.timestamps
# end
#
- # You may also pass a different UUID generation function from +uuid-ossp+
- # or another library.
+ # You may also pass a custom stored procedure that returns a UUID or use a
+ # different UUID generation function from another library.
#
# Note that setting the UUID primary key default value to +nil+ will
# require you to assure that you always provide a UUID value before saving
# a record (as primary keys cannot be +nil+). This might be done via the
# +SecureRandom.uuid+ method and a +before_save+ callback, for instance.
def primary_key(name, type = :primary_key, **options)
- options[:default] = options.fetch(:default, "uuid_generate_v4()") if type == :uuid
+ options[:default] = options.fetch(:default, "gen_random_uuid()") if type == :uuid
super
end
@@ -11,11 +11,12 @@ module ActiveRecord
# end
#
- # By default, this will use the +uuid_generate_v4()+ function from the
- # +uuid-ossp+ extension, which MUST be enabled on your database. To enable
- # the +uuid-ossp+ extension, you can use the +enable_extension+ method in your
- # migrations. To use a UUID primary key without +uuid-ossp+ enabled, you can
- # set the +:default+ option to +nil+:
+ # By default, this will use the +gen_random_uuid()+ function from the
+ # +pgcrypto+ extension (only PostgreSQL >= 9.4), or +uuid_generate_v4()+
+ # function from the +uuid-ossp+ extension. To enable the appropriate
+ # extension, which is a requirement, you can use the +enable_extension+
+ # method in your migrations. To use a UUID primary key without any of
+ # of extensions, you can set the +:default+ option to +nil+:
#
# create_table :stuffs, id: false do |t|